@@ -1,6 +1,6 @@
 from typing import Dict, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Extra
 
 
 class Discriminator(BaseModel):
@@ -25,6 +25,7 @@ class Discriminator(BaseModel):
     """
 
     class Config:
+        extra = Extra.ignore
         schema_extra = {
             "examples": [
                 {
