@@ -1,6 +1,6 @@
 from typing import Optional
 
-from pydantic import AnyUrl, BaseModel
+from pydantic import AnyUrl, BaseModel, Extra
 
 from .contact import Contact
 from .license import License
@@ -47,6 +47,7 @@ class Info(BaseModel):
     """
 
     class Config:
+        extra = Extra.ignore
         schema_extra = {
             "examples": [
                 {
