@@ -1,6 +1,6 @@
-from typing import Dict, Optional
+from typing import Dict, Optional, Union
 
-from pydantic import AnyUrl, BaseModel
+from pydantic import AnyUrl, BaseModel, Extra
 
 
 class OAuthFlow(BaseModel):
@@ -8,21 +8,21 @@ class OAuthFlow(BaseModel):
     Configuration details for a supported OAuth Flow
     """
 
-    authorizationUrl: Optional[AnyUrl] = None
+    authorizationUrl: Optional[Union[AnyUrl, str]] = None
     """
     **REQUIRED** for `oauth2 ("implicit", "authorizationCode")`.
     The authorization URL to be used for this flow.
     This MUST be in the form of a URL.
     """
 
-    tokenUrl: Optional[AnyUrl] = None
+    tokenUrl: Optional[Union[AnyUrl, str]] = None
     """
     **REQUIRED** for `oauth2 ("password", "clientCredentials", "authorizationCode")`.
     The token URL to be used for this flow.
     This MUST be in the form of a URL.
     """
 
-    refreshUrl: Optional[AnyUrl] = None
+    refreshUrl: Optional[Union[AnyUrl, str]] = None
     """
     The URL to be used for obtaining refresh tokens. This MUST be in the form of a URL.
     """
@@ -35,6 +35,7 @@ class OAuthFlow(BaseModel):
     """
 
     class Config:
+        extra = Extra.ignore
         schema_extra = {
             "examples": [
                 {
@@ -46,5 +47,11 @@ class OAuthFlow(BaseModel):
                     "tokenUrl": "https://example.com/api/oauth/token",
                     "scopes": {"write:pets": "modify pets in your account", "read:pets": "read your pets"},
                 },
+                {
+                    "authorizationUrl": "/api/oauth/dialog",    # issue #5: allow relative path
+                    "tokenUrl": "/api/oauth/token",             # issue #5: allow relative path
+                    "refreshUrl": "/api/oauth/token",           # issue #5: allow relative path
+                    "scopes": {"write:pets": "modify pets in your account", "read:pets": "read your pets"},
+                },
             ]
         }
