@@ -1,9 +1,9 @@
 """
-OpenAPI v3.0.3 schema types, created according to the specification:
-https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.3.md
+OpenAPI v3.1.0 schema types, created according to the specification:
+https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.1.0.md
 
 The type orders are according to the contents of the specification:
-https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.3.md#table-of-contents
+https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.1.0.md#table-of-contents
 """
 
 from .open_api import OpenAPI
@@ -36,3 +36,7 @@ from .security_scheme import SecurityScheme
 from .oauth_flows import OAuthFlows
 from .oauth_flow import OAuthFlow
 from .security_requirement import SecurityRequirement
+
+# resolve forward references
+Encoding.update_forward_refs(Header=Header)
+Schema.update_forward_refs()
