@@ -1,6 +1,6 @@
 from typing import Any, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Extra
 
 
 class Example(BaseModel):
@@ -30,9 +30,11 @@ class Example(BaseModel):
     This provides the capability to reference examples that cannot easily be included in JSON or YAML documents.
     
     The `value` field and `externalValue` field are mutually exclusive.
+    See the rules for resolving [Relative References](#relativeReferencesURI).
     """
 
     class Config:
+        extra = Extra.ignore
         schema_extra = {
             "examples": [
                 {"summary": "A foo example", "value": {"foo": "bar"}},
