@@ -1,4 +1,4 @@
-from pydantic import Field
+from pydantic import Extra, Field
 
 from .parameter import Parameter
 
@@ -17,7 +17,8 @@ class Header(Parameter):
     param_in = Field(default="header", const=True, alias="in")
 
     class Config:
-        allow_population_by_field_name = True,
+        extra = Extra.ignore
+        allow_population_by_field_name = True
         schema_extra = {
             "examples": [
                 {"description": "The number of allowed requests in the current period", "schema": {"type": "integer"}}
